@@ -9,7 +9,7 @@ use AnyEvent;
 use Mac::FSEvents;
 use Carp;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 sub _init {
     my $self = shift;
@@ -50,12 +50,14 @@ AnyEvent::Filesys::Notify::Role::FSEvents - Use Mac::FSEvents to watch for chang
 
 =head1 VERSION
 
-version 1.22
+version 1.23
+
+=head1 AUTHOR
+
+Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the BSD support for IO::KQueue Dave Hayes E<lt>dave@jetcafe.orgE<gt> Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
-
 =over 4
 
 =item *
@@ -70,12 +72,16 @@ Dave Hayes E<lt>dave@jetcafe.orgE<gt>
 
 Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
 
+=item *
+
+Ettore Di Giacinto (@mudler)
+
+=item *
+
+Martin Barth (@ufobat)
+
 =back
 
-=head1 AUTHOR
-
-Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
-
 =head1 SOURCE
 
 Source repository is at L<https://github.com/mvgrimes/AnyEvent-Filesys-Notify>.
